@@ -1,199 +1,229 @@
-#' Traditional IRT item fit statistics
+#' Traditional IRT Item Fit Statistics
 #'
-#' @description This function computes traditional IRT item fit statistics (i.e., \eqn{\chi^{2}} fit statistic (e.g., Bock, 1960; Yen, 1981),
-#' loglikelihood ratio \eqn{\chi^{2}} fit statistic (\eqn{G^{2}}; McKinley & Mills, 1985), and infit and outfit statistics (Ames et al., 2015)) and returns
-#' contingency tables to compute the \eqn{\chi^{2}} and \eqn{G^{2}} fit statistics. Note that caution is needed in interpreting the infit and
-#' outfit statistics for non-Rasch models. The saved object of this function, especially the object of contingency tables,
-#' is used in the function of \code{\link{plot.irtfit}} to draw a raw and standardized residual plots (Hambleton et al., 1991).
+#' This function computes traditional IRT item fit statistics, including the
+#' \eqn{\chi^{2}} fit statistic (e.g., Bock, 1960; Yen, 1981),
+#' the log-likelihood ratio \eqn{\chi^{2}} fit statistic (\eqn{G^{2}}; McKinley
+#' & Mills, 1985), and the infit and outfit statistics (Ames et al., 2015). It
+#' also returns contingency tables used to compute the \eqn{\chi^{2}} and
+#' \eqn{G^{2}} statistics.
 #'
-#' @param x A data frame containing the item metadata (e.g., item parameters, number of categories, models ...), an object of class \code{\link{est_item}}
-#' obtained from the function \code{\link{est_item}}, or an object of class \code{\link{est_irt}} obtained from the function \code{\link{est_irt}}.
-#' The data frame of item metadata can be easily obtained using the function \code{\link{shape_df}}. See below for more detail.
-#' @param score A vector of examinees' ability estimates.
-#' @param data A matrix containing examinees' response data for the items in the argument \code{x}. A row and column indicate
-#' the examinees and items, respectively.
-#' @param group.method A character string indicating how to group examinees along the ability scale for computing the \eqn{\chi^{2}} and \eqn{G^{2}} fit statistics.
-#' Available methods are "equal.width" for grouping examinees by dividing the ability scale into intervals of equal width and "equal.freq"
-#' for grouping examinees by dividing the ability scale into intervals with equal frequencies of examinees. However, "equal.freq" does not
-#' always guarantee exactly the same frequency of examinees for all groups. Default is "equal.width". To divide the ability scale, the range
-#' of ability scale and the number of divided groups must be specified in the arguments of \code{range.score} and \code{n.width}, respectively.
-#' See below for details.
-#' @param n.width An integer value to specify the number of divided groups along the ability scale. Default is 10. See below for more detail.
-#' @param loc.theta A character string to indicate the location of ability point at each group (or interval) where the expected probabilities
-#' of score categories are calculated using the IRT models. Available locations are "average" for computing the expected probability
-#' at the average point of examinees' ability estimates in each group and "middle" for computing the expected probability at the midpoint of each group.
-#' Default is "average".
-#' @param range.score A vector of two numeric values to restrict the range of ability scale. All ability estimates less than
-#' the first value are transformed to the first value. All ability estimates greater than the second value are transformed to the second value.
-#' If NULL, the minimum and maximum values of ability estimates in the argument \code{score} is used as the range of ability scale. Note that
-#' selection of grouping method in the argument \code{group.method} has nothing to do with the range of ability scale. Default is NULL.
-#' @param D A scaling factor in IRT models to make the logistic function as close as possible to the normal ogive function (if set to 1.7).
-#' Default is 1.
-#' @param alpha A numeric value to specify significance \eqn{\alpha}-level of the hypothesis test for the \eqn{\chi^{2}} and \eqn{G^{2}} fit statistics.
-#' Default is .05.
-#' @param missing A value indicating missing values in the response data set. Default is NA.
-#' @param overSR A numeric value to specify a criterion to find ability groups (or intervals) which have standardized residuals
-#' greater than the specified value. Default is 2.
-#' @param min.collapse An integer value to indicate the minimum frequency of cells to be collapsed when computing the \eqn{\chi^{2}} and \eqn{G^{2}}
-#' fit statistics. Neighboring interval groups will be collapsed to avoid expected interval frequencies less than the specified minimum cell frequency.
-#' Default is 1.
-#' @param pcm.loc A vector of integer values indicating the locations of partial credit model (PCM) items whose slope parameters are fixed
+#' @inheritParams est_score
+#' @param x A data frame containing item metadata (e.g., item parameters,
+#'   number of categories, IRT model types, etc.); or an object of class
+#'   `est_irt` obtained from [irtQ::est_irt()], or `est_item` from
+#'   [irtQ::est_item()].
+#'
+#'   See [irtQ::est_irt()] or [irtQ::simdat()] for more details about the item
+#'   metadata. This data frame can be easily created using the
+#'   [irtQ::shape_df()] function.
+#' @param score A numeric vector containing examinees' ability estimates
+#'   (theta values).
+#' @param group.method A character string specifying the method used to group
+#'   examinees along the ability scale when computing the \eqn{\chi^{2}} and
+#'   \eqn{G^{2}} fit statistics. Available options are:
+#'    - `"equal.width"`: Divides the ability scale into intervals of equal width.
+#'    - `"equal.freq"`: Divides the examinees into groups with (approximately)
+#'    equal numbers of examinees.
+#'
+#'   Note that `"equal.freq"` does not guarantee exactly equal group sizes
+#'   due to ties in ability estimates. Default is `"equal.width"`.
+#'   The number of groups and the range of the ability scale are controlled by
+#'   the `n.width` and `range.score` arguments, respectively.
+#' @param n.width An integer specifying the number of intervals (groups) into which
+#' the ability scale is divided for computing the fit statistics. Default is 10.
+#' @param loc.theta A character string indicating the point on the ability scale
+#'  at which the expected category probabilities are calculated for each group.
+#'  Available options are:
+#'  - `"average"`: Uses the average ability estimate of examinees within each group.
+#'  - `"middle"`: Uses the midpoint of each group's ability interval.
+#'
+#'  Default is `"average"`.
+#' @param range.score A numeric vector of length two specifying the lower and upper
+#'   bounds of the ability scale. Ability estimates below the lower bound or above the
+#'   upper bound are truncated to the respective bound. If `NULL`, the observed minimum
+#'   and maximum of the `score` vector are used. Note that this range restriction is
+#'   independent of the grouping method specified in `group.method`.
+#'   Default is `NULL`.
+#' @param alpha A numeric value specifying the significance level (\eqn{\alpha}) for
+#'   the hypothesis tests of the \eqn{\chi^{2}} and \eqn{G^{2}} item fit statistics.
+#'   Default is `0.05`.
+#' @param overSR A numeric threshold used to identify ability groups (intervals)
+#'   whose standardized residuals exceed the specified value. This is used to
+#'   compute the proportion of misfitting groups per item. Default is 2.
+#' @param min.collapse An integer specifying the minimum expected frequency required
+#'   for a cell in the contingency table. Neighboring groups will be merged if any
+#'   expected cell frequency falls below this threshold when computing the
+#'   \eqn{\chi^{2}} and \eqn{G^{2}} statistics. Default is 1.
+#' @param pcm.loc A vector of integers indicating the locations (indices) of
+#'   partial credit model (PCM) items for which slope parameters are fixed.
 #' @param ... Further arguments passed to or from other methods.
 #'
-#' @details A specific form of a data frame should be used for the argument \code{x}. The first column should have item IDs,
-#' the second column should contain unique score category numbers of the items, and the third column should include IRT models being fit to the items.
-#' The available IRT models are "1PLM", "2PLM", "3PLM", and "DRM" for dichotomous item data, and "GRM" and "GPCM" for polytomous item data.
-#' Note that "DRM" covers all dichotomous IRT models (i.e, "1PLM", "2PLM", and "3PLM") and "GRM" and "GPCM" represent the graded
-#' response model and (generalized) partial credit model, respectively. The next columns should include the item parameters of the fitted IRT models.
-#' For dichotomous items, the fourth, fifth, and sixth columns represent the item discrimination (or slope), item difficulty, and
-#' item guessing parameters, respectively. When "1PLM" and "2PLM" are specified in the third column, NAs should be inserted in the sixth column
-#' for the item guessing parameters. For polytomous items, the item discrimination (or slope) parameters should be included in the
-#' fourth column and the item difficulty (or threshold) parameters of category boundaries should be contained from the fifth to the last columns.
-#' When the number of unique score categories differs between items, the empty cells of item parameters should be filled with NAs.
-#' In the \pkg{irtQ} package, the item difficulty (or threshold) parameters of category boundaries for GPCM are expressed as
-#' the item location (or overall difficulty) parameter subtracted by the threshold parameter for unique score categories of the item.
-#' Note that when an GPCM item has \emph{K} unique score categories, \emph{K-1} item difficulty parameters are necessary because
-#' the item difficulty parameter for the first category boundary is always 0. For example, if an GPCM item has five score categories,
-#' four item difficulty parameters should be specified. An example of a data frame with a single-format test is as follows:
-#' \tabular{lrlrrrrr}{
-#'   ITEM1  \tab 2 \tab 1PLM \tab 1.000 \tab  1.461 \tab         NA \cr
-#'   ITEM2  \tab 2 \tab 2PLM \tab 1.921 \tab -1.049 \tab         NA \cr
-#'   ITEM3  \tab 2 \tab 3PLM \tab 1.736 \tab  1.501 \tab  0.203 \cr
-#'   ITEM4  \tab 2 \tab 3PLM \tab 0.835 \tab -1.049 \tab  0.182 \cr
-#'   ITEM5  \tab 2 \tab DRM \tab 0.926 \tab  0.394 \tab  0.099
-#' }
-#' And an example of a data frame for a mixed-format test is as follows:
-#' \tabular{lrlrrrrr}{
-#'   ITEM1  \tab 2 \tab 1PLM \tab 1.000 \tab  1.461 \tab         NA \tab         NA \tab         NA\cr
-#'   ITEM2  \tab 2 \tab 2PLM \tab 1.921 \tab -1.049 \tab         NA \tab         NA \tab         NA\cr
-#'   ITEM3  \tab 2 \tab 3PLM \tab 0.926 \tab  0.394 \tab  0.099 \tab         NA \tab         NA\cr
-#'   ITEM4  \tab 2 \tab DRM \tab 1.052 \tab -0.407 \tab  0.201 \tab         NA \tab         NA\cr
-#'   ITEM5  \tab 4 \tab GRM  \tab 1.913 \tab -1.869 \tab -1.238 \tab -0.714 \tab         NA \cr
-#'   ITEM6  \tab 5 \tab GRM  \tab 1.278 \tab -0.724 \tab -0.068 \tab  0.568 \tab  1.072\cr
-#'   ITEM7  \tab 4 \tab GPCM  \tab 1.137 \tab -0.374 \tab  0.215 \tab  0.848 \tab         NA \cr
-#'   ITEM8  \tab 5 \tab GPCM  \tab 1.233 \tab -2.078 \tab -1.347 \tab -0.705 \tab -0.116
-#' }
-#' See \code{IRT Models} section in the page of \code{\link{irtQ-package}} for more detail about the IRT models used in the \pkg{irtQ} package.
-#' An easier way to create a data frame for the argument \code{x} is by using the function \code{\link{shape_df}}.
+#' @details
+#' To compute the \eqn{\chi^2} and \eqn{G^2} item fit statistics, the `group.method`
+#' argument determines how the ability scale is divided into groups:
+#' - `"equal.width"`: Examinees are grouped based on intervals of equal width a
+#'  long the ability scale.
+#' - `"equal.freq"`: Examinees are grouped such that each group contains
+#'  (approximately) the same number of individuals.
 #'
-#' To calculate the \eqn{\chi^{2}} and \eqn{G^{2}} fit statistics, two methods are used in the argument \code{group.method} to divide the ability scale
-#' into several groups. If \code{group.method = "equal.width"}, the examinees are grouped based on equal length of intervals.
-#' If \code{group.method = "equal.freq"}, the examinees are grouped so that all groups have equal frequencies. However, the grouping method
-#' of "equal.freq" does guarantee that every group has the exactly same frequency of examinees. This is because the examinees are divided by
-#' the same size of quantile.
+#' Note that `"equal.freq"` does not guarantee *exactly* equal frequencies across
+#' all groups, since grouping is based on quantiles.
 #'
-#' When dividing the ability scale into intervals to compute the \eqn{\chi^{2}} and \eqn{G^{2}} fit statistics, the intervals should be wide enough not to include
-#' too small number of examinees. On the other hand, the interval should be narrow enough to include homogeneous examinees in terms of ability
-#' (Hambleton et al, 1991). Thus, if you want to divide the ability scale into other than ten groups, you need to specify the number of groups
-#' in the argument \code{n.width}. Yen (1981) fixed the number of groups to 10, whereas Bock (1960) allowed for any number of groups.
+#' When dividing the ability scale into intervals to compute the \eqn{\chi^2}
+#' and \eqn{G^2} fit statistics, the intervals should be:
+#' - **Wide enough** to ensure that each group contains a sufficient number of
+#'  examinees (to avoid unstable estimates),
+#' - **Narrow enough** to ensure that examinees within each group are relatively
+#'  homogeneous in ability (Hambleton et al., 1991).
 #'
-#' Regarding degrees of freedom (\emph{df}), the \eqn{\chi^{2}} is assumed to be distributed approximately as a chi-square with \emph{df} equal to
-#' the number of groups less the number of the IRT model parameters (Ames et al., 2015) whereas the \eqn{G^{2}} is assumed to be distributed approximately
-#' as a chi-square with \emph{df} equal to the number of groups (Ames et al., 2015; Muraki & Bock, 2003)
+#' If you want to divide the ability scale into a number of groups other than
+#' the default of 10, specify the desired number using the `n.width` argument.
+#' For reference:
+#' - Yen (1981) used 10 fixed-width groups,
+#' - Bock (1960) allowed for flexibility in the number of groups.
 #'
-#' Note that if "DRM" is specified for an item in the item metadata set, the item is considered as "3PLM" to compute degrees of freedom of
-#' the \eqn{\chi^{2}} fit statistic.
+#' Regarding degrees of freedom (*df*):
+#' - The \eqn{\chi^2} statistic is approximately chi-square distributed with
+#'   degrees of freedom equal to the number of ability groups minus the number
+#'   of item parameters (Ames et al., 2015).
+#' - The \eqn{G^2} statistic is approximately chi-square distributed with
+#'   degrees of freedom equal to the number of ability groups (Ames et al., 2015;
+#'   Muraki & Bock, 2003).
 #'
-#' @return This function returns an object of class \code{\link{irtfit}}. Within this object, several internal objects are contained such as:
-#' \item{fit_stat}{A data frame containing the results of three IRT fit statistics (i.e., \eqn{\chi^{2}} and \eqn{G^{2}}, infit, outfit statistics) across
-#' all evaluated items. In the data frame, the columns indicate item's ID, \eqn{\chi^{2}} fit statistic, \eqn{G^{2}} fit statistic, degrees of freedom for the \eqn{\chi^{2}},
-#' degrees of freedom for the \eqn{G^{2}}, critical value for the \eqn{\chi^{2}}, critical value for the \eqn{G^{2}}, p-value for the \eqn{\chi^{2}},
-#' p-value for the \eqn{G^{2}}, outfit statistic, infit statistic, the number of examinees used to compute the five fit statistics, and the proportion of
-#' ability groups (or intervals), before collapsing the cells, that have standardized residuals greater than the specified criterion in the argument \code{overSR},
-#' respectively.}
-#' \item{contingency.fitstat}{A list of contingency tables used to compute the \eqn{\chi^{2}} and \eqn{G^{2}} fit statistics for all items.
-#' Note that the collapsing cell strategy is implemented to these contingency tables.}
-#' \item{contingency.plot}{A list of contingency tables used to draw a raw and standardized residual plots (Hambleton et al., 1991) in the function of
-#' \code{\link{plot.irtfit}}. Note that the collapsing cell strategy is \emph{not} implemented to these contingency tables.}
-#' \item{individual.info}{A list of data frames including individual residual and variance values. Those information are used to compute
-#' infit and outfit statistics.}
-#' \item{item_df}{The item metadata specified in the argument \code{x}.}
-#' \item{ancillary}{A list of ancillary information used in the item fit analysis.}
+#'   Note that if `"DRM"` is specified for an item in the item metadata set,
+#'   the item is treated as a `"3PLM"` when computing the degrees of freedom
+#'   for the \eqn{\chi^{2}} fit statistic.
+#'
+#' Note that infit and outfit statistics should be interpreted with caution when
+#' applied to non-Rasch models. The returned object—particularly the contingency
+#' tables—can be passed to [irtQ::plot.irtfit()] to generate raw and standardized
+#' residual plots (Hambleton et al., 1991).
+#'
+#' @return This function returns an object of class `irtfit`, which includes
+#' the following components:
+#'
+#'   \item{fit_stat}{A data frame containing the results of three IRT item fit statistics—
+#'   \eqn{\chi^{2}}, \eqn{G^{2}}, infit, and outfit—for all evaluated items.
+#'   Each row corresponds to one item, and the columns include:
+#'   the item ID; \eqn{\chi^{2}} statistic; \eqn{G^{2}} statistic;
+#'   degrees of freedom for \eqn{\chi^{2}} and \eqn{G^{2}};
+#'   critical values and p-values for both statistics;
+#'   outfit and infit values;
+#'   the number of examinees used to compute these statistics;
+#'   and the proportion of ability groups (prior to cell collapsing) that have
+#'   standardized residuals greater than the threshold specified in the `overSR` argument.}
+#'
+#'   \item{contingency.fitstat}{A list of contingency tables used to compute the
+#'   \eqn{\chi^{2}} and \eqn{G^{2}} fit statistics for all items. Note that the
+#'   cell-collapsing strategy is applied to these tables to ensure sufficient
+#'   expected frequencies.}
+#'
+#'   \item{contingency.plot}{A list of contingency tables used to generate raw
+#'   and standardized residual plots (Hambleton et al., 1991) via the
+#'   [irtQ::plot.irtfit()]. Note that these tables are based on the original,
+#'   uncollapsed groupings.}
+#'
+#'   \item{individual.info}{A list of data frames containing individual residuals
+#'   and corresponding variance values. This information is used to compute infit
+#'   and outfit statistics.}
+#'
+#'   \item{item_df}{A data frame containing the item metadata provided in the
+#'   argument `x`.}
+#'
+#'   \item{ancillary}{A list of ancillary information used during the item fit
+#'   analysis.}
 #'
 #' @author Hwanggyu Lim \email{hglim83@@gmail.com}
 #'
-#' @seealso \code{\link{plot.irtfit}}, \code{\link{shape_df}}, \code{\link{est_item}}
+#' @seealso [irtQ::plot.irtfit()], [irtQ::shape_df()], [irtQ::est_irt()],
+#' [irtQ::est_item()]
 #'
-#' @references
-#' Ames, A. J., & Penfield, R. D. (2015). An NCME Instructional Module on Item-Fit Statistics for Item Response Theory Models.
-#' \emph{Educational Measurement: Issues and Practice, 34}(3), 39-48.
+#' @references Ames, A. J., & Penfield, R. D. (2015). An NCME Instructional
+#' Module on Item-Fit Statistics for Item Response Theory Models.
+#' *Educational Measurement: Issues and Practice, 34*(3), 39-48.
 #'
-#' Bock, R.D. (1960), \emph{Methods and applications of optimal scaling}. Chapel Hill, NC: L.L. Thurstone Psychometric Laboratory.
+#' Bock, R.D. (1960), *Methods and applications of optimal scaling*. Chapel
+#' Hill, NC: L.L. Thurstone Psychometric Laboratory.
 #'
-#' Hambleton, R. K., Swaminathan, H., & Rogers, H. J. (1991).\emph{Fundamentals of item response theory}. Newbury Park, CA: Sage.
+#' Hambleton, R. K., Swaminathan, H., & Rogers, H. J. (1991).*Fundamentals of
+#' item response theory*. Newbury Park, CA: Sage.
 #'
-#' McKinley, R., & Mills, C. (1985). A comparison of several goodness-of-fit statistics.
-#' \emph{Applied Psychological Measurement, 9}, 49-57.
+#' McKinley, R., & Mills, C. (1985). A comparison of several goodness-of-fit
+#' statistics.
+#' *Applied Psychological Measurement, 9*, 49-57.
 #'
-#' Muraki, E. & Bock, R. D. (2003). PARSCALE 4: IRT item analysis and test scoring for rating
-#' scale data [Computer Program]. Chicago, IL: Scientific Software International. URL http://www.ssicentral.com
+#' Muraki, E. & Bock, R. D. (2003). PARSCALE 4: IRT item analysis and test
+#' scoring for rating scale data (Computer Software). Chicago, IL: Scientific
+#' Software International. URL http://www.ssicentral.com
 #'
-#' Wells, C. S., & Bolt, D. M. (2008). Investigation of a nonparametric procedure for assessing goodness-of-fit in
-#' item response theory. \emph{Applied Measurement in Education, 21}(1), 22-40.
+#' Wells, C. S., & Bolt, D. M. (2008). Investigation of a nonparametric
+#' procedure for assessing goodness-of-fit in item response theory. *Applied
+#' Measurement in Education, 21*(1), 22-40.
 #'
-#' Yen, W. M. (1981). Using simulation results to choose a latent trait model. \emph{Applied Psychological Measurement, 5}, 245-262.
+#' Yen, W. M. (1981). Using simulation results to choose a latent trait model.
+#' *Applied Psychological Measurement, 5*, 245-262.
 #'
 #' @examples
 #' \donttest{
-#' ## example 1
-#' ## use the simulated CAT data
-#' # find the location of items that have more than 10,000 responses
+#' ## Example 1
+#' ## Use the simulated CAT data
+#' # Identify items with more than 10,000 responses
 #' over10000 <- which(colSums(simCAT_MX$res.dat, na.rm = TRUE) > 10000)
 #'
-#' # select the items that have more than 10,000 responses
+#' # Select items with more than 10,000 responses
 #' x <- simCAT_MX$item.prm[over10000, ]
 #'
-#' # select the response data for the items
+#' # Extract response data for the selected items
 #' data <- simCAT_MX$res.dat[, over10000]
 #'
-#' # select the examinees' abilities
+#' # Extract examinees' ability estimates
 #' score <- simCAT_MX$score
 #'
-#' # compute fit statistics
+#' # Compute item fit statistics
 #' fit1 <- irtfit(
 #'   x = x, score = score, data = data, group.method = "equal.width",
 #'   n.width = 10, loc.theta = "average", range.score = NULL, D = 1, alpha = 0.05,
 #'   missing = NA, overSR = 2
 #' )
 #'
-#' # fit statistics
+#' # View the fit statistics
 #' fit1$fit_stat
 #'
-#' # contingency tables
+#' # View the contingency tables used to compute fit statistics
 #' fit1$contingency.fitstat
 #'
 #'
-#' ## example 2
-#' ## import the "-prm.txt" output file from flexMIRT
+#' ## Example 2
+#' ## Import the "-prm.txt" output file from flexMIRT
 #' flex_sam <- system.file("extdata", "flexmirt_sample-prm.txt", package = "irtQ")
 #'
-#' # select the first two dichotomous items and last polytomous item
+#' # Select the first two dichotomous items and the last polytomous item
 #' x <- bring.flexmirt(file = flex_sam, "par")$Group1$full_df[c(1:2, 55), ]
 #'
-#' # generate examinees' abilities from N(0, 1)
+#' # Generate ability values from a standard normal distribution
 #' set.seed(10)
 #' score <- rnorm(1000, mean = 0, sd = 1)
 #'
-#' # simulate the response data
+#' # Simulate response data
 #' data <- simdat(x = x, theta = score, D = 1)
 #'
-#' # compute fit statistics
+#' # Compute item fit statistics
 #' fit2 <- irtfit(
 #'   x = x, score = score, data = data, group.method = "equal.freq",
 #'   n.width = 11, loc.theta = "average", range.score = c(-4, 4), D = 1, alpha = 0.05
 #' )
 #'
-#' # fit statistics
+#' # View the fit statistics
 #' fit2$fit_stat
 #'
-#' # contingency tables
+#' # View the contingency tables used to compute fit statistics
 #' fit2$contingency.fitstat
 #'
-#' # residual plots for the first item (dichotomous item)
+#' # Plot raw and standardized residuals for the first item (dichotomous)
 #' plot(x = fit2, item.loc = 1, type = "both", ci.method = "wald",
 #'      show.table = TRUE, ylim.sr.adjust = TRUE)
 #'
-#' # residual plots for the third item (polytomous item)
+#' # Plot raw and standardized residuals for the third item (polytomous)
 #' plot(x = fit2, item.loc = 3, type = "both", ci.method = "wald",
 #'      show.table = FALSE, ylim.sr.adjust = TRUE)
 #' }
@@ -201,13 +231,26 @@
 #' @export
 irtfit <- function(x, ...) UseMethod("irtfit")
 
-#' @describeIn irtfit Default method to compute the traditional IRT item fit statistics for a data frame \code{x} containing the item metadata.
+#' @describeIn irtfit Default method for computing traditional IRT item fit
+#' statistics using a data frame `x` that contains item metadata.
 #' @import dplyr
 #' @export
 #'
-irtfit.default <- function(x, score, data, group.method = c("equal.width", "equal.freq"),
-                           n.width = 10, loc.theta = "average", range.score = NULL, D = 1, alpha = 0.05,
-                           missing = NA, overSR = 2, min.collapse = 1, pcm.loc = NULL, ...) {
+irtfit.default <- function(x,
+                           score,
+                           data,
+                           group.method = c("equal.width", "equal.freq"),
+                           n.width = 10,
+                           loc.theta = "average",
+                           range.score = NULL,
+                           D = 1,
+                           alpha = 0.05,
+                           missing = NA,
+                           overSR = 2,
+                           min.collapse = 1,
+                           pcm.loc = NULL,
+                           ...) {
+
   # match.call
   cl <- match.call()
 
@@ -307,13 +350,21 @@ irtfit.default <- function(x, score, data, group.method = c("equal.width", "equa
 }
 
 
-#' @describeIn irtfit An object created by the function \code{\link{est_item}}.
+#' @describeIn irtfit An object created by the function [irtQ::est_item()].
 #' @import dplyr
 #' @export
 #'
-irtfit.est_item <- function(x, group.method = c("equal.width", "equal.freq"),
-                            n.width = 10, loc.theta = "average", range.score = NULL, alpha = 0.05,
-                            missing = NA, overSR = 2, min.collapse = 1, pcm.loc = NULL, ...) {
+irtfit.est_item <- function(x,
+                            group.method = c("equal.width", "equal.freq"),
+                            n.width = 10,
+                            loc.theta = "average",
+                            range.score = NULL,
+                            alpha = 0.05,
+                            missing = NA,
+                            overSR = 2,
+                            min.collapse = 1,
+                            pcm.loc = NULL,
+                            ...) {
   # match.call
   cl <- match.call()
 
@@ -419,13 +470,23 @@ irtfit.est_item <- function(x, group.method = c("equal.width", "equal.freq"),
 }
 
 
-#' @describeIn irtfit An object created by the function \code{\link{est_irt}}.
+#' @describeIn irtfit An object created by the function [irtQ::est_irt()].
 #' @import dplyr
 #' @export
 #'
-irtfit.est_irt <- function(x, score, group.method = c("equal.width", "equal.freq"),
-                           n.width = 10, loc.theta = "average", range.score = NULL, alpha = 0.05,
-                           missing = NA, overSR = 2, min.collapse = 1, pcm.loc = NULL, ...) {
+irtfit.est_irt <- function(x,
+                           score,
+                           group.method = c("equal.width", "equal.freq"),
+                           n.width = 10,
+                           loc.theta = "average",
+                           range.score = NULL,
+                           alpha = 0.05,
+                           missing = NA,
+                           overSR = 2,
+                           min.collapse = 1,
+                           pcm.loc = NULL,
+                           ...) {
+
   # match.call
   cl <- match.call()
 
