@@ -1,67 +1,71 @@
-#' Loglikelihood of Ability Parameters
+#' Log-Likelihood of Ability Parameters
 #'
-#' @description This function computes the loglikelihood of ability parameters
-#' given the item parameters and response data.
+#' This function computes the log-likelihood values for a set of ability
+#' parameters, given item parameters and response data
 #'
-#' @param x A data frame containing the item metadata (e.g., item parameters, number
-#' of score categories, models). This can be created easily using the \code{\link{shape_df}}
-#' function. See \code{\link{est_irt}}, \code{\link{irtfit}}, \code{\link{info}},
-#' or \code{\link{simdat}} for more details about the item metadata.
-#' @param data A matrix representing examinees' response data for the items in \code{x}.
-#' Each row and column corresponds to an examinee and an item, respectively.
-#' @param theta A numeric vector of ability parameters for which the loglikelihood
-#' values will be computed.
-#' @param D A scaling factor in IRT models that adjusts the logistic function to
-#' approximate the normal ogive function (set to 1.7). The default is 1.
-#' @param method A character string specifying the scoring method. Options include
-#' "ML" for maximum likelihood estimation,  "MLF" for maximum likelihood estimation
-#' with fences, and "MAP" for maximum a posteriori estimation. The default method is "MLE".
-#' @param norm.prior A numeric vector of two elements indicating the mean and standard
-#' deviation of the normal prior distribution. These parameters are used to obtain
-#' the Gaussian quadrature points and corresponding weights from the normal distribution.
-#' Default is c(0,1). This parameter is ignored if \code{method} is "ML" or "MLF".
-#' @param fence.a A numeric value defining the item slope parameter (a-parameter) for
-#' the two imaginary items in the MLF method. Default is 3.0.
-#' @param fence.b A numeric vector of two elements specifying the lower and upper fences
-#' of item difficulty parameters (b-parameters) for the two imaginary items in the MLF method.
-#' If \code{fence.b = NULL}, the \code{range} values are used to set the fences.
-#' The default is NULL.
-#' @param missing A value used to denote missing values in the response data set. Default is NA.
+#' @inheritParams catsib
+#' @inheritParams est_score
+#' @param theta A numeric vector of ability values at which to evaluate the
+#'   log-likelihood function.
+#' @param method A character string specifying the estimation method. Available
+#'   options include:
+#'   - `"ML"`: Maximum Likelihood Estimation
+#'   - `"MLF"`: Maximum Likelihood Estimation with Fences
+#'   - `"MAP"`: Maximum A Posteriori Estimation
+#'   Default is `"ML"`.
+#' @param norm.prior A numeric vector of length two specifying the mean and
+#'   standard deviation of the normal prior distribution (used only when `method
+#'   = "MAP"`). Default is `c(0, 1)`. Ignored for `"ML"` and `"MLF"`.
 #'
-#' @details The function computes the loglikelihood value of the ability parameter given
-#' the item parameters and response data for each item. As an example, to assess the loglikelihoods
-#' of abilities for two examinees who have taken the same test items specified in \code{x}, supply
-#' their item response data matrix with two rows in \code{data} and a vector of ability values
-#' for which loglikelihood needs to be computed in \code{theta}.
+#' @details This function evaluates the log-likelihood of a given ability
+#' (`theta`) for one or more examinees, based on item parameters (`x`) and item
+#' response data (`data`).
 #'
-#' @return A data frame of loglikelihood values. Each row indicates the ability parameter
-#' for which the loglikelihood was computed, and each column represents a response pattern.
+#' If `method = "MLF"` is selected, the function appends two virtual "fence"
+#' items to the item pool with fixed parameters. These artificial items help
+#' avoid unstable likelihood functions near the boundaries of the ability scale.
+#'
+#' For example, to compute the log-likelihood curves of two examinees' responses
+#' to the same test items, supply a 2-row matrix to `data` and a vector of
+#' ability values to `theta`.
+#'
+#' @return A data frame of log-likelihood values.
+#' - Each **row** corresponds to an ability value (`theta`).
+#' - Each **column** corresponds to an examinee’s response pattern.
 #'
 #' @examples
 #' ## Import the "-prm.txt" output file from flexMIRT
 #' flex_sam <- system.file("extdata", "flexmirt_sample-prm.txt", package = "irtQ")
 #'
-#' # Read item parameters and transform them into item metadata
-#' x <- bring.flexmirt(file=flex_sam, "par")$Group1$full_df
+#' # Read item parameters and convert them to item metadata
+#' x <- bring.flexmirt(file = flex_sam, "par")$Group1$full_df
 #'
-#' # Generate examinees' abilities from N(0, 1)
+#' # Generate ability values from N(0, 1)
 #' set.seed(10)
-#' score <- rnorm(5, mean=0, sd=1)
+#' score <- rnorm(5, mean = 0, sd = 1)
 #'
-#' # Simulate the response data
-#' data <- simdat(x=x, theta=score, D=1)
+#' # Simulate response data
+#' data <- simdat(x = x, theta = score, D = 1)
 #'
-#' # Specify the ability values for which the loglikelihood values will be computed
+#' # Specify ability values for log-likelihood evaluation
 #' theta <- seq(-3, 3, 0.5)
 #'
-#' # Compute the loglikelihood values (using the MLE method)
-#' llike_score(x=x, data=data, theta=theta, D=1, method="ML")
+#' # Compute log-likelihood values (using MLE)
+#' llike_score(x = x, data = data, theta = theta, D = 1, method = "ML")
 #'
 #' @export
 #' @importFrom reshape2 melt
 #' @import dplyr
-llike_score <- function(x, data, theta, D = 1, method = "ML", norm.prior = c(0, 1),
-                        fence.a = 3.0, fence.b = NULL, missing = NA) {
+llike_score <- function(x,
+                        data,
+                        theta,
+                        D = 1,
+                        method = "ML",
+                        norm.prior = c(0, 1),
+                        fence.a = 3.0,
+                        fence.b = NULL,
+                        missing = NA) {
+
   # check if the data set is a vector of an examinee
   if (is.vector(data)) {
     data <- rbind(data)
